
# Class: relationship quantifier




URI: [biolink:RelationshipQuantifier](https://w3id.org/biolink/vocab/RelationshipQuantifier)

![img](http://yuml.me/diagram/nofunky;dir:TB/class/\[RelationshipQuantifier]^-\[SpecificityQuantifier],%20\[RelationshipQuantifier]^-\[SensitivityQuantifier],%20\[RelationshipQuantifier]^-\[FrequencyQuantifier])

## Children

 * [FrequencyQuantifier](FrequencyQuantifier.md)
 * [SensitivityQuantifier](SensitivityQuantifier.md)
 * [SpecificityQuantifier](SpecificityQuantifier.md)

## Referenced by class


## Attributes

